# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['copernicusmarine',
 'copernicusmarine.aioretry',
 'copernicusmarine.catalogue_parser',
 'copernicusmarine.command_line_interface',
 'copernicusmarine.core_functions',
 'copernicusmarine.download_functions',
 'copernicusmarine.python_interface']

package_data = \
{'': ['*']}

install_requires = \
['aiohttp>=3.8.5',
 'boto3>=1.25',
 'cachier>=2.2.1',
 'click>=8.0.4',
 'dask>=2022',
 'lxml>=4.9.0',
 'nest-asyncio>=1.5.8',
 'netCDF4>=1.5.4',
 'pystac>=1.8.3',
 'requests>=2.27.1',
 'semver>=3.0.2',
 'setuptools>=68.2.2',
 'tqdm>=4.65.0',
 'xarray>=2023.4.0',
 'zarr>=2.13.3']

entry_points = \
{'console_scripts': ['copernicusmarine = '
                     'copernicusmarine.command_line_interface.copernicus_marine:command_line_interface']}

setup_kwargs = {
    'name': 'copernicusmarine',
    'version': '1.1.0',
    'description': '',
    'long_description': '\n<h1 align="center">Copernicus Marine Service Toolbox (CLI & Python)</h1>\n<div align="center">\n  <a href="https://pypi.org/project/copernicusmarine/"><img src="https://img.shields.io/pypi/v/copernicusmarine.svg?style=flat-square" alt="PyPI" /></a>\n  <a href="https://pypi.org/project/copernicusmarine/"><img src="https://img.shields.io/pypi/pyversions/copernicusmarine.svg?style=flat-square" alt="PyPI Supported Versions" /></a>\n  <a href="https://pypi.org/project/copernicusmarine/"><img src="https://img.shields.io/badge/platform-windows | linux | macos-lightgrey?style=flat-square" alt="Supported Platforms" /></a>\n  <a href="https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12"><img src="https://img.shields.io/badge/licence-EUPL-lightblue?style=flat-square" alt="Licence" /></a>\n</div>\n\n![Copernicus Marine Service and Mercator Ocean international logos](https://www.mercator-ocean.eu/wp-content/uploads/2022/05/Cartouche_CMEMS_poisson_MOi.png)\n\n## Features\nThe `copernicusmarine` offers capabilities through both **Command Line Interface (CLI)** and **Python API**:\n- **Metadata Information**: List and retrieve metadata information on all variables, datasets, products, and their associated documentation.\n- **Subset Datasets**: Subset datasets to extract only the parts of interest, in preferred format, such as Analysis-Ready Cloud-Optimized (ARCO) Zarr or NetCDF file format.\n- **Advanced Filters**: Apply simple or advanced filters to get multiple files, in original formats like NetCDF/GeoTIFF, via direct Marine Data Store connections.\n- **No Quotas**: Enjoy no quotas, neither on volume size nor bandwidth.\n\n## Installation\nFor installation, multiple options are available depending on your setup:\n\n### Mamba | Conda\nA `conda` package is available on [Anaconda](https://anaconda.org/conda-forge/copernicusmarine).\n\nYou can install it using `mamba` (or conda) through the `conda-forge` channel with the following command:\n```bash\nmamba install conda-forge::copernicusmarine --yes\n```\n\nTo upgrade the Toolbox with mamba (or conda):\n```bash\nmamba update --name copernicusmarine copernicusmarine --yes\n```\n\n### Docker\nA docker image is also available here: [https://hub.docker.com/r/copernicusmarine/copernicusmarine](https://hub.docker.com/r/copernicusmarine/copernicusmarine)\n\nFirst step is to pull the container image:\n```bash\ndocker pull copernicusmarine/copernicusmarine:latest\n```\n\nThen run it:\n```bash\ndocker run -it --rm copernicusmarine/copernicusmarine --version\n```\n\n### Pip\nOtherwise, if you already have an environment (safer to clone it), the package can be installed using the `pip` command:\n```bash\npython -m pip install copernicusmarine\n```\n\nAnd to **upgrade the package** to the newest available version, run:\n```bash\npython -m pip install copernicusmarine --upgrade\n```\n\n## User Guide\nFor more comprehensive details on how to use the `copernicusmarine` Toolbox, please refer to our [Help Center](https://help.marine.copernicus.eu/en/collections/9054839-copernicus-marine-toolbox-guide). It ensures a smooth migration for existing users of legacy services such as MOTU, OPeNDAP or FTP.\n\n### General configuration\n\n#### Cache Usage\nCachier library is used for caching part of the requests (as result of `describe` or `login`). By default, the cache will be located in the home folder. If you need to change the location of the cache, you can set the environment variable `COPERNICUSMARINE_CACHE_DIRECTORY` to point to the desired directory:\n- on **UNIX** platforms: `export COPERNICUSMARINE_CACHE_DIRECTORY=<PATH>`\n- on **Windows** platforms: `set COPERNICUSMARINE_CACHE_DIRECTORY=<PATH>`\n\n#### Disable SSL\nA global SSL context is used when making HTTP calls using the `copernicusmarine` Toolbox. For some reason, it can lead to unexpected behavior depending on your network configuration. You can set the `COPERNICUSMARINE_DISABLE_SSL_CONTEXT` environment variable to any value to globally disable the usage of SSL in the toolbox:\n- on **UNIX** platforms: `export COPERNICUSMARINE_DISABLE_SSL_CONTEXT=True`\n- on **Windows** platforms: `set COPERNICUSMARINE_DISABLE_SSL_CONTEXT=True`\n\n## Command Line Interface (CLI)\n\n### The `--help` option\nTo discover commands and their available options, consider appending `--help` on any command line.\n\nExample:\n```bash\ncopernicusmarine --help\n```\n\nReturns:\n```bash\nUsage: copernicusmarine [OPTIONS] COMMAND [ARGS]...\n\nOptions:\n  -V, --version  Show the version and exit.\n  -h, --help     Show this message and exit.\n\nCommands:\n  describe  Print Copernicus Marine catalog as JSON.\n  get       Download originally produced data files.\n  login     Create a configuration file with your Copernicus Marine credentials.\n  subset    Download subsets of datasets as NetCDF files or Zarr stores.\n```\n\n### Command `describe`\nRetrieve metadata information about all products/datasets and display as JSON output:\n```bash\ncopernicusmarine describe --include-datasets\n```\n\nThe JSON output can also be saved as follows:\n```bash\ncopernicusmarine describe --include-datasets > all_datasets_copernicusmarine.json\n```\n\n### Command `login`\nCreate a single configuration file `.copernicusmarine-credentials` allowing to access all Copernicus Marine Data Store data services. By default, the file is saved in user\'s home directory.\n\nExample:\n```bash\n> copernicusmarine login\nusername : johndoe\npassword :\nINFO - Configuration files stored in /Users/foo/.copernicusmarine\n```\n\nIf `.copernicusmarine-credentials` already exists, the user is asked for confirmation to overwrite (`--overwrite`/`--overwrite-configuration-file`).\n\nYou can use the `--skip-if-user-logged-in` option to skip the configuration file overwrite if the user is already logged in.\n\n#### Access points migration and evolution\nIf you still have a configuration for legacy services (e.g. `~/motuclient/motuclient-python.ini`, `~/.netrc` or `~/_netrc`) in your home directory, it will automatically be taken into account with commands `get` and `subset` without the need for running the `login` command.\nIf the configuration files are already available in another directory, when running commands `subset` or `get`, you can use the `--credentials-file` option to point to the files.\n\n### Command `subset`\nRemotely subset a dataset, based on variable names, geographical and temporal parameters.\n\nExample:\n```bash\ncopernicusmarine subset --dataset-id cmems_mod_ibi_phy_my_0.083deg-3D_P1D-m --variable thetao --variable so --start-datetime 2021-01-01 --end-datetime 2021-01-03 --minimum-longitude 0.0 --maximum-longitude 0.1 --minimum-latitude 28.0 --maximum-latitude 28.1\n```\nReturns:\n```bash\nINFO - 2024-04-03T10:18:18Z - <xarray.Dataset> Size: 3kB\nDimensions:    (depth: 50, latitude: 2, longitude: 1, time: 3)\nCoordinates:\n  * depth      (depth) float32 200B 0.5058 1.556 2.668 ... 5.292e+03 5.698e+03\n  * latitude   (latitude) float32 8B 28.0 28.08\n  * longitude  (longitude) float32 4B 0.08333\n  * time       (time) datetime64[ns] 24B 2021-01-01 2021-01-02 2021-01-03\nData variables:\n    thetao     (time, depth, latitude, longitude) float32 1kB dask.array<chunksize=(3, 1, 2, 1), meta=np.ndarray>\n    so         (time, depth, latitude, longitude) float32 1kB dask.array<chunksize=(3, 1, 2, 1), meta=np.ndarray>\nAttributes: (12/20)\n    Conventions:               CF-1.0\n    bulletin_date:             2020-12-01\n    ...                        ...\n    references:                http://marine.copernicus.eu\n    copernicusmarine_version:  1.1.0\nINFO - 2024-04-03T10:18:18Z - Estimated size of the dataset file is 0.002 MB.\n\nDo you want to proceed with download? [Y/n]:\n```\n\nBy default, after the display of the summary of the dataset subset, a download confirmation is asked. To skip this confirmation, use the option `--force-download`.\n\n#### Note about `--subset-method` option\nBy default, the `subset` feature uses the `nearest` method of xarray. By specifying `--subset-method strict`, you can only request dimension strictly inside the dataset, useful for **operational use-case**.\n\n#### Note about longitude range\nOptions `--minimum-longitude` and `--maximum-longitude` work as follows:\n- If the result of the substraction ( `--maximum-longitude` minus `--minimum-longitude` ) is superior or equal to 360, then return the full dataset.\n- If the requested longitude range:\n  - **does not cross** the antemeridian, then return the dataset between range -180 and 180.\n  - **does cross** the antemeridian, then return the dataset between range 0 and 360.\n\nNote that you can request any longitudes you want. A modulus is applied to bring the result between -180° and 360°. For example, if you request [530, 560], the result dataset will be in [170, 200].\n\n\n#### Note about `--netcdf-compression-enabled` and `--netcdf-compression-level` options\nWhen subsetting data, if you decide to write your data as a NetCDF file (which is the default behavior), then you can provide the extra option `--netcdf-compression-enabled`. The downloaded file will be lighter but it will take more time to write it (because of the compression task). If you don\'t provide it, the task will be faster, but the file heavier.\nOtherwise, if you decide to write your data in Zarr format (`.zarr` extension), the original compression used in the Copernicus Marine Data Store will be applied, which means that the download task will be fast **and** the file compressed. In that case, you cannot use the `--netcdf-compression-enabled`.\n\nHere are the default parameters added to xarray in the background when using the option: `{\'zlib\': True, \'complevel\': 1, \'contiguous\': False, \'shuffle\': True}`\n\nIn addition to this option, you can also provide the `--netcdf-compression-level` option and customize the NetCDF compression level between 0 (no compression) and 9 (maximal compression).\n\n#### Note about `--netcdf3-compatible` option\nThe `--netcdf3-compatible` option has been added to allow the downloaded dataset to be compatible with the netCDF3 format. It uses the `format="NETCDF3_CLASSIC"` of the xarray [to_netcdf](https://docs.xarray.dev/en/latest/generated/xarray.Dataset.to_netcdf.html) method.\n\n### Command `get`\nDownload the dataset file(s) as originally produced, based on the datasetID or the path to files.\n\nExample:\n```bash\ncopernicusmarine get --dataset-id cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m --service original-files\n```\nReturns:\n```bash\nINFO - 2024-04-03T11:39:18Z - Dataset version was not specified, the latest one was selected: "202211"\nINFO - 2024-04-03T11:39:18Z - Dataset part was not specified, the first one was selected: "default"\nINFO - 2024-04-03T11:39:18Z - Service was not specified, the default one was selected: "original-files"\nINFO - 2024-04-03T11:39:18Z - Downloading using service original-files...\nINFO - 2024-04-03T11:39:19Z - You requested the download of the following files:\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m_202211/CMEMS_v5r1_IBI_PHY_MY_NL_01yav_19930101_19931231_R20221101_RE01.nc - 8.83 MB - 2023-11-12T23:47:13Z\n[... truncated for brevity..]\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m_202211/CMEMS_v5r1_IBI_PHY_MY_NL_01yav_20120101_20121231_R20221101_RE01.nc - 8.62 MB - 2023-11-12T23:47:14Z\nPrinted 20 out of 29 files\n\nTotal size of the download: 252.94 MB\nDo you want to proceed with download? [Y/n]:\n```\n\nBy default:\n- After the header displays a summary of the request, a download confirmation is asked. To skip this user\'s action, add option `--force-download`.\n- Files are downloaded to the current directory applying the original folder structure. To avoid this behavior, add `--no-directories` and specify a destination with `-o/--output-directory`.\n\nOption `--show-outputnames` displays the full paths of the output files, if required.\n\nOption `--create-file-list` only creates a file containing the names of the targeted files instead of downloading them. You have to input a file name, e.g. `--create-file-list my_files.txt`. The format needs to be `.txt` or `.csv`:\n\n- If the user inputs a filename that ends in `.txt`, then the file contains only the full s3 path to the targeted files and is compatible with the `--file-list` option.\n\nExample:\n```bash\ncopernicusmarine get --dataset-id cmems_mod_ibi_phy_my_0.083deg-3D_P1M-m --filter "*2021*" --create-file-list selected_files_for_2021.txt\n```\nThe content of `selected_files_for_2021.txt` would be:\n```\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1M-m_202012/2021/CMEMS_v5r1_IBI_PHY_MY_PdE_01mav_20210101_20210131_R20230101_RE01.nc\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1M-m_202012/2021/CMEMS_v5r1_IBI_PHY_MY_PdE_01mav_20210201_20210228_R20230101_RE01.nc\n[... truncated for brevity..]\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1M-m_202012/2021/CMEMS_v5r1_IBI_PHY_MY_PdE_01mav_20211101_20211130_R20230101_RE01.nc\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1M-m_202012/2021/CMEMS_v5r1_IBI_PHY_MY_PdE_01mav_20211201_20211231_R20230101_RE01.nc\n```\n\n- If the user inputs a filename that ends in `.csv` the file contains the following columns, separated by a comma: `filename`, `size` (in Bytes), `last_modified_datetime`, and `etag`. It is **not** compatible "as is" with the `--file-list` option and would need further post-processing from user\'s side.\n\nExample:\n```bash\ncopernicusmarine get --dataset-id cmems_mod_ibi_phy_my_0.083deg-3D_P1M-m --filter "*2021*" --create-file-list selected_files_for_2021.csv\n```\n The content of `selected_files_for_2021.csv` would be:\n```\nfilename,size,last_modified_datetime,etag\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1M-m_202012/2021/CMEMS_v5r1_IBI_PHY_MY_PdE_01mav_20210101_20210131_R20230101_RE01.nc,12295906,2023-11-12 23:47:05.466000+00:00,"e8a7e564f676a08bf601bcdeaebdc563"\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1M-m_202012/2021/CMEMS_v5r1_IBI_PHY_MY_PdE_01mav_20210201_20210228_R20230101_RE01.nc,12436177,2023-11-12 23:47:05.540000+00:00,"d4a22dfb6c7ed85860c4a122c45eb953"\n[... truncated for brevity..]\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1M-m_202012/2021/CMEMS_v5r1_IBI_PHY_MY_PdE_01mav_20211101_20211130_R20230101_RE01.nc,12386940,2023-11-12 23:47:06.358000+00:00,"ea15d1f70fcc7f2ce404184d983530ff"\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1M-m_202012/2021/CMEMS_v5r1_IBI_PHY_MY_PdE_01mav_20211201_20211231_R20230101_RE01.nc,12398208,2023-11-12 23:47:06.456000+00:00,"585f49867aaefa2ce9d6e68dd468b5e1"\n```\nIf specified, no other action will be performed.\n\n\n#### Note about sync option\nOption `--sync` allows to download original files only if not exist and not up to date. The Toolbox checks the destination folder against the source folder. It can be combined with filters. Note that if set with `--overwrite-output-data`, the latter will be ignored.\nThe logic is largely inspired from [s5cmd package sync command](https://github.com/peak/s5cmd#sync).\nOption `--sync-delete` will work as `--sync` with the added fonctionnality that it deletes any local file that has not been found on the remote server. Note that the files found on the server are also filtered. Hence, a file present locally might be deleted even if it is on the server because, for example, the executed `get` command contains a filter that excludes this specific file.\n\nLimitations:\n- `--sync` is not compatible with `--no-directories`.\n- `--sync` only works with `--dataset-version`.\n- `--sync` functionality is not available for datasets with several parts (like INSITU or static datasets for example).\n\n#### Note about filtering options\nOption `--filter` allows to specify a Unix shell-style wildcard pattern (see [fnmatch — Unix filename pattern matching](https://docs.python.org/3/library/fnmatch.html)) and select specific files:\n```bash\ncopernicusmarine get --dataset-id cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m --filter "*01yav_200[0-2]*"\n```\nReturns:\n```bash\nINFO - 2024-04-03T11:51:15Z - Dataset version was not specified, the latest one was selected: "202211"\nINFO - 2024-04-03T11:51:15Z - Dataset part was not specified, the first one was selected: "default"\nINFO - 2024-04-03T11:51:15Z - Service was not specified, the default one was selected: "original-files"\nINFO - 2024-04-03T11:51:15Z - Downloading using service original-files...\nINFO - 2024-04-03T11:51:17Z - You requested the download of the following files:\ns3://mdl-native/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m_202211/CMEMS_v5r1_IBI_PHY_MY_NL_01yav_20000101_20001231_R20221101_RE01.nc - 8.93 MB\ns3://mdl-native/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m_202211/CMEMS_v5r1_IBI_PHY_MY_NL_01yav_20010101_20011231_R20221101_RE01.nc - 8.91 MB\ns3://mdl-native/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m_202211/CMEMS_v5r1_IBI_PHY_MY_NL_01yav_20020101_20021231_R20221101_RE01.nc - 8.75 MB\n\nTotal size of the download: 26.59 MB\nDo you want to proceed with download? [Y/n]:\n```\n\nOption `--regex` allows to specify a regular expression for more advanced files selection:\n\n```bash\ncopernicusmarine get -i cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m --regex ".*01yav_20(00|01|02).*.nc"\n```\nReturns:\n```bash\nINFO - 2024-04-03T11:52:43Z - Dataset version was not specified, the latest one was selected: "202211"\nINFO - 2024-04-03T11:52:43Z - Dataset part was not specified, the first one was selected: "default"\nINFO - 2024-04-03T11:52:43Z - Service was not specified, the default one was selected: "original-files"\nINFO - 2024-04-03T11:52:43Z - Downloading using service original-files...\nINFO - 2024-04-03T11:52:44Z - You requested the download of the following files:\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m_202211/CMEMS_v5r1_IBI_PHY_MY_NL_01yav_20000101_20001231_R20221101_RE01.nc - 8.93 MB - 2023-11-12T23:47:13Z\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m_202211/CMEMS_v5r1_IBI_PHY_MY_NL_01yav_20010101_20011231_R20221101_RE01.nc - 8.91 MB - 2023-11-12T23:47:13Z\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m_202211/CMEMS_v5r1_IBI_PHY_MY_NL_01yav_20020101_20021231_R20221101_RE01.nc - 8.75 MB - 2023-11-12T23:47:13Z\n\nTotal size of the download: 26.59 MB\nDo you want to proceed with download? [Y/n]:\n```\n\nOption `--file-list` allows to specify a list of files for more advanced files selection.\nThe file can contain complete absolute paths for each target file (default behavior) or only a partial path defined by the user, as shown below.\n\nExample of `file_list.txt` with absolute paths:\n```txt\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1M-m_202012/2021/CMEMS_v5r1_IBI_PHY_MY_PdE_01mav_20210101_20210131_R20230101_RE01.nc\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1M-m_202012/2021/CMEMS_v5r1_IBI_PHY_MY_PdE_01mav_20210201_20210228_R20230101_RE01.nc\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1M-m_202012/2021/CMEMS_v5r1_IBI_PHY_MY_PdE_01mav_20210301_20210331_R20230101_RE01.nc\n```\n\nExample of `file_list.txt` with partial paths matching the absolute paths (equivalent to previous example):\n```txt\nCMEMS_v5r1_IBI_PHY_MY_NL_01yav_20000101_20001231_R20221101_RE01.nc\nCMEMS_v5r1_IBI_PHY_MY_NL_01yav_20010101_20011231_R20221101_RE01.nc\nCMEMS_v5r1_IBI_PHY_MY_NL_01yav_20020101_20021231_R20221101_RE01.nc\n```\n> **_NOTE:_** This option is compatible with the file generated by the `--create-file-list` option if you generated a ".txt" file.\n\nThen the following command:\n```bash\ncopernicusmarine get -i cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m --file-list file_list.txt\n```\nReturns:\n```bash\nINFO - 2024-04-03T12:57:44Z - Dataset version was not specified, the latest one was selected: "202211"\nINFO - 2024-04-03T12:57:44Z - Dataset part was not specified, the first one was selected: "default"\nINFO - 2024-04-03T12:57:44Z - Service was not specified, the default one was selected: "original-files"\nINFO - 2024-04-03T12:57:44Z - Downloading using service original-files...\nINFO - 2024-04-03T12:57:45Z - You requested the download of the following files:\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m_202211/CMEMS_v5r1_IBI_PHY_MY_NL_01yav_20000101_20001231_R20221101_RE01.nc - 8.93 MB - 2023-11-12T23:47:13Z\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m_202211/CMEMS_v5r1_IBI_PHY_MY_NL_01yav_20010101_20011231_R20221101_RE01.nc - 8.91 MB - 2023-11-12T23:47:13Z\ns3://mdl-native-10/native/IBI_MULTIYEAR_PHY_005_002/cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m_202211/CMEMS_v5r1_IBI_PHY_MY_NL_01yav_20020101_20021231_R20221101_RE01.nc - 8.75 MB - 2023-11-12T23:47:13Z\n\nTotal size of the download: 26.59 MB\nDo you want to proceed with download? [Y/n]:\n```\n\nAlso, there is a specific command `--index-parts` to retrieve the index files of INSITU datasets (as listed on the [Copernicus Marine File Browser](https://data.marine.copernicus.eu/product/INSITU_BLK_PHYBGCWAV_DISCRETE_MYNRT_013_034/files?subdataset=cmems_obs-ins_blk_phybgcwav_mynrt_na_irr_202311--ext--history&path=INSITU_BLK_PHYBGCWAV_DISCRETE_MYNRT_013_034%2Fcmems_obs-ins_blk_phybgcwav_mynrt_na_irr_202311%2F)).\n> **_NOTE:_** In the future, it is planned to have the index files for those datasets directly available through the `--filter`, `--regex` and/or `--file-list` options. Meanwhile, check this [Help Center article for a working example](https://help.marine.copernicus.eu/en/articles/9133855-how-to-download-insitu-data-using-index-files).\n\n\nThen the following command:\n```\ncopernicusmarine get --dataset-id cmems_obs-ins_blk_phybgcwav_mynrt_na_irr --index-parts\n```\nReturns:\n```\nINFO - 2024-04-03T12:58:40Z - Dataset version was not specified, the latest one was selected: "202311"\nINFO - 2024-04-03T12:58:40Z - Dataset part was not specified, the first one was selected: "history"\nINFO - 2024-04-03T12:58:40Z - You forced selection of service: original-files\nINFO - 2024-04-03T12:58:40Z - Downloading using service original-files...\nINFO - 2024-04-03T12:58:41Z - You requested the download of the following files:\ns3://mdl-native-08/native/INSITU_BLK_PHYBGCWAV_DISCRETE_MYNRT_013_034/cmems_obs-ins_blk_phybgcwav_mynrt_na_irr_202311/index_history.txt - 333.13 kB - 2024-04-02T08:40:30Z\ns3://mdl-native-08/native/INSITU_BLK_PHYBGCWAV_DISCRETE_MYNRT_013_034/cmems_obs-ins_blk_phybgcwav_mynrt_na_irr_202311/index_latest.txt - 466.38 kB - 2024-04-03T12:51:52Z\ns3://mdl-native-08/native/INSITU_BLK_PHYBGCWAV_DISCRETE_MYNRT_013_034/cmems_obs-ins_blk_phybgcwav_mynrt_na_irr_202311/index_monthly.txt - 1.51 MB - 2024-03-05T18:09:43Z\ns3://mdl-native-08/native/INSITU_BLK_PHYBGCWAV_DISCRETE_MYNRT_013_034/cmems_obs-ins_blk_phybgcwav_mynrt_na_irr_202311/index_platform.txt - 209.27 kB - 2024-04-03T08:33:37Z\n\nTotal size of the download: 2.52 MB\nDo you want to proceed with download? [Y/n]:\n```\n\n### Shared options\nBoth `subset` and `get` commands provide these options:\n\n#### Option `--overwrite-output-data`\nWhen specified, the existing files will be overwritten.\nOtherwise, if the files already exist on destination, new ones with a unique index will be created once the download has been accepted (or once `--force-download` is provided).\n\n#### Option `--create-template`\nOption to create a file in your current directory containing request parameters. If specified, no other action will be performed.\nIt will create the following files depending on the feature:\n- `subset`\nExample:\n```bash\ncopernicusmarine subset --create-template\n```\nReturns:\n```txt\nINFO - 2024-04-04T14:38:09Z - Template created at: subset_template.json\n```\n- `get`\nExample:\n```bash\ncopernicusmarine get --create-template\n```\nReturns:\n```txt\nINFO - 2024-04-04T14:38:09Z - Template created at: get_template.json\n```\n\n#### Option `--request-file`\nThis option allows to specify request parameters but in a provided `.json` file, useful for batch processing.\nYou can try the following templates or use the `--create-template` option to create both `subset` or `get` template request files.\n\n- Template for `subset` data request:\n```json\n{\n    "dataset_id": "cmems_mod_glo_phy-thetao_anfc_0.083deg_P1D-m",\n    "start_datetime": "2022-04-11",\n    "end_datetime": "2023-08-11",\n    "minimum_longitude": -182.79,\n    "maximum_longitude": -179.69,\n    "minimum_latitude": -40,\n    "maximum_latitude": -36,\n    "minimum_depth": 0,\n    "maximum_depth": 0,\n    "variables": ["thetao"],\n    "output_directory": "./data/",\n    "force_download": true\n}\n```\n\nExample:\n```bash\ncopernicusmarine subset --request-file template_subset_data_request.json\n```\n\n- Template for `get` data request:\n```json\n{\n    "dataset_id": "cmems_mod_ibi_phy_my_0.083deg-3D_P1Y-m",\n    "filter": "*01yav_200[0-2]*",\n    "force_download": false,\n    "log_level": "INFO",\n    "no_directories": false,\n    "no_metadata_cache": false,\n    "output_directory": "./data/",\n    "overwrite_output_data": false,\n    "overwrite_metadata_cache": false,\n    "show_outputnames": true\n}\n```\n\nExample:\n```bash\ncopernicusmarine get --request-file template_get_data_request.json\n```\n\n#### Option `--credentials-file`\nYou can use the `--credentials-file` option to point to a credentials file. The file can be either `.copernicusmarine-credentials`, `motuclient-python.ini`, `.netrc` or `_netrc`.\n\n#### Option `--dataset-version`\nYou can use the `--dataset-version` option to fetch a specific dataset version. Particularly useful to keep an operational chain working when an evolution impact the chosen dataset.\n\n#### Option `--dataset-part`\nYou can use the `--dataset-part` option to fecth a specific part for the chosen dataset version.\n\n#### Option `--log-level`\nSet the details printed to console by the command (based on standard logging library).\nAvailable values are: `[DEBUG|INFO|WARN|ERROR|CRITICAL|QUIET]`\n\n## Python package (API)\nThe `copernicusmarine` exposes a Python interface to allow you to [call commands as functions](https://marine.copernicus.eu/python-interface).\n\n## Documentation\nA detailed standalone API documentation is under construction and will come at a later stage. For the moment, see the [Help Center](https://help.marine.copernicus.eu/en/collections/9054839-copernicus-marine-toolbox-guide).\n\n## Contribution\nWe welcome contributions from the community to enhance this package. If you find any issues or have suggestions for improvements, please check out our [Report Template](https://help.marine.copernicus.eu/en/articles/8218546-reporting-an-issue-or-feature-request).\n\n## Future improvements & Roadmap\nTo keep up to date with the most recent and planned advancements, including revisions, corrections, and feature requests generated from users\' feedback, please refer to our [Roadmap](https://help.marine.copernicus.eu/en/articles/8218641-next-milestones-and-roadmap).\n\n## Join the community\nGet in touch!\n- Create your [Copernicus Marine Account](https://data.marine.copernicus.eu/register?redirect=%2Fproducts)\n- [Log in](https://data.marine.copernicus.eu/login?redirect=%2Fproducts) and chat with us (bottom right corner of [Copernicus Marine Service](https://marine.copernicus.eu/))\n- Join our [training workshops](https://marine.copernicus.eu/services/user-learning-services)\n- Network y/our [Copernicus Stories](https://twitter.com/cmems_eu)\n- Watch [our videos](https://www.youtube.com/channel/UC71ceOVy7WtVC7F04BKoEew)\n## Licence\nLicensed under the [EUPL](https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12)\n',
    'author': 'Copernicus Marine User Support',
    'author_email': 'servicedesk.cmems@mercator-ocean.eu',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<3.13',
}


setup(**setup_kwargs)
